@@ -7,7 +7,7 @@ function(nstates,ncases,formula=~1,data=NULL,values=NULL, ...) {
 	
 	# initial probabilities model, depending on covariates init(=~1 by default)
 	if(formula==~1) {
-		initModel <- transInit(~1,data=data.frame(rep(1,ncases)),nst=nstates,family=multinomial(),pstart=values)
+		initModel <- transInit(~1,data=data.frame(rep(1,ncases)),nst=nstates,family=multinomial(link="identity"),pstart=values)
 	} else {
 		if(is.null(data)) {
 			stop("'Argument initdata missing while the init model is non-trivial")
