@@ -33,8 +33,8 @@ setMethod("GLMresponse",
 		if(family$family=="gaussian") {
 			parameters$sd <- 1
 			constr <- list(
-				parup = rep(Inf,ncol(y)+1),
-				parlow = c(rep(-Inf,ncol(y)),0)
+				parup = rep(Inf,ncol(x)+1),
+				parlow = c(rep(-Inf,ncol(x)),0)
 			)
 		}
 		if(family$family=="binomial") {
