@@ -46,14 +46,35 @@ setMethod("fit","MULTINOMresponse",
 
 setMethod("logDens","MULTINOMresponse",
 	function(object) {
-		log(rowSums(object@y*predict(object)))
+		if(all(rowSums(object@y)==1)) {
+			return(log(rowSums(object@y*predict(object))))
+		} else {
+			nr <- nrow(object@y)
+			res <- matrix(nr=nr)
+			pr <- predict(object)
+			for(i in 1:nrow(object@y)) {
+				res[i,1] <- dmultinom(object@y[i,],pr=pr[i,])
+			}
+			return(log(res))
+		}
 	}
 )
 
 setMethod("dens","MULTINOMresponse",
 	function(object,log=FALSE) {
-		if(log) log(rowSums(object@y*predict(object)))
-		else rowSums(object@y*predict(object))
+		if(all(rowSums(object@y)==1)) {
+			if(log) return(log(rowSums(object@y*predict(object))))
+			else return(rowSums(object@y*predict(object)))
+		} else {
+			nr <- nrow(object@y)
+			res <- matrix(nr=nr)
+			pr <- predict(object)
+			for(i in 1:nrow(object@y)) {
+				res[i,1] <- dmultinom(object@y[i,],pr=pr[i,])
+			}
+			if(log) return(log(res)) 
+			else return(res)
+		}
 	}
 )
 
@@ -85,3 +106,14 @@ setMethod("simulate",signature(object="MULTINOMresponse"),
 		return(sims)
 	}
 )
+
+setMethod("getdf","MULTINOMresponse",
+	function(object) {
+		npar <- sum(!object@fixed)
+		if(object@family$link == "identity") {
+			npar <- npar-1
+			if(npar<0) npar <- 0
+		}
+		npar
+	}
+)
